# frozen_string_literal: true

require 'jwt'
require 'jwt_api_auth/engine'
require 'jwt_api_auth/helpers'
require 'jwt_api_auth/authentication'

module JwtApiAuth
  ActiveSupport.on_load(:action_controller) do
    include JwtApiAuth::Helpers
  end

  mattr_accessor :token_lifetime
  self.token_lifetime = 1.day

  mattr_accessor :refresh_token_lifetime
  self.refresh_token_lifetime = 1.week

  mattr_accessor :token_secret
  self.token_secret = -> { Rails.application.secrets.secret_key_base }

  mattr_accessor :model
  self.model = :user

  mattr_accessor :refresh_token_model
  self.refresh_token_model = :refresh_token

  mattr_accessor :token_audience
  self.token_audience = nil

  def self.setup
    yield self
  end
end
