# frozen_string_literal: true

module JwtApiAuth
  module Authentication
    extend ActiveSupport::Concern

    included do
      before_action :authenticate_user

      rescue_from ::JWT::DecodeError do
        head :unauthorized
      end
    end

    private

    def authenticate_user
      token = request.headers['Authorization']&.split('Bearer ')&.last
      options = { algorithm: 'HS256' }

      if JwtApiAuth.token_audience.present?
        options[:aud] = JwtApiAuth.token_audience.map(&:to_s)
        options[:verify_aud] = true
      end

      ::JWT.decode token, JwtApiAuth.token_secret.call, true, options

      head :unauthorized unless token
    end
  end
end
